Tools
=====

here some more information about the tools contained in this package and how to use them.

In general if you are looking for something which does not depend on AiiDA and may not be FLEUR specific, 
the place to look for is the `masci-tools repository <https://github.com/JuDFTteam/masci-tools>`_ and 
its `documentation <https://masci-tools.readthedocs.io/en/latest/?badge=latest>`_.
This includes:

- parsers for files
- utility for xml
- plot methods

Tools and utility which does depend on AiiDA but is not FLEUR specific you find in the 
`aiida-jutools repository <https://github.com/JuDFTteam/aiida-jutools>`_

This includes:

- StructureData curation
- Meta AiiDA database analysis

Since so far we lack a in detail documentation of tools and utility within aiida-fleur you are referenced to the 
:ref:`automatic documenation of tools and utility <aiidafleur_tools>`.
